@@ -1,11 +1,10 @@
-import sys
-from StringIO import StringIO
-from tiddlyweb.model.recipe import Recipe
-from tiddlyweb.config import config
-from tiddlywebplugins.utils import get_store
 
+from tiddlyweb.config import config
+from tiddlyweb.model.recipe import Recipe
 from tiddlyweb.store import HOOKS
 
+from .fixtures import get_store
+
 
 OUTPUT = ''
 
@@ -21,7 +20,6 @@ def recipe_get_hook(store, recipe):
 
 
 def setup_module(module):
-    module.store = get_store(config)
     HOOKS['recipe']['put'].append(recipe_put_hook)
     HOOKS['recipe']['get'].append(recipe_get_hook)
 
@@ -34,6 +32,7 @@ def teardown_module(module):
 def test_put_recipe():
     global OUTPUT
     assert OUTPUT == ''
+    store = get_store(config)
     recipe = Recipe('keen')
     store.put(recipe)
     store.get(recipe)
