@@ -6,23 +6,25 @@ import py.test
 
 from tiddlyweb.model.bag import Bag
 from tiddlyweb.model.tiddler import Tiddler
-from tiddlyweb.web.validator import validate_bag, validate_tiddler, InvalidTiddlerError
+from tiddlyweb.web.validator import (validate_bag, validate_tiddler,
+        InvalidTiddlerError)
 import tiddlyweb.web.validator
 
+
 def check_for_text(tiddler, environ):
     if 'foobar' not in tiddler.text:
         raise InvalidTiddlerError('missing "foobar" in tiddler.text')
 
+
 def modify_text(tiddler, environ):
     tiddler.text = tiddler.text.replace('foobar', 'FOOBAR')
 
+
 tiddlyweb.web.validator.TIDDLER_VALIDATORS = [
         check_for_text,
         modify_text,
         ]
 
-def setup_module(module):
-    pass
 
 def test_validate_tiddler():
     tiddler = Tiddler('foobar', 'barney')
@@ -37,6 +39,7 @@ def test_validate_tiddler():
 
     assert 'FOOBAR' in tiddler.text
 
+
 def test_validate_bag_desc():
     bag = Bag('barney')
     bag.desc = '<script>alert("foo");</script>'
@@ -44,4 +47,3 @@ def test_validate_bag_desc():
     validate_bag(bag)
 
     assert bag.desc == '&lt;script&gt;alert("foo");&lt;/script&gt;'
-
