@@ -1,5 +1,6 @@
 """
-Limit a group of entities using a syntax similar to SQL Limit:
+A :py:mod:`filter <tiddlyweb.filters>` type to limit a group of entities
+using a syntax similar to SQL Limit::
 
     limit=<index>,<count>
     limit=<count>
@@ -10,12 +11,10 @@ import itertools
 
 def limit_parse(count='0'):
     """
-    Parse the argument of a limit filter
-    for a count and index argument, return
-    a function which does the limiting.
+    Parse the argument of a ``limit`` :py:mod:`filter <tiddlyweb.filters>`
+    for a count and index argument, return a function which does the limiting.
 
-    Exceptions while parsing are passed
-    up the stack.
+    Exceptions while parsing are passed up the stack.
     """
     index = '0'
     if ',' in count:
@@ -31,8 +30,7 @@ def limit_parse(count='0'):
 
 def limit(entities, count=0, index=0):
     """
-    Make a slice of a list of entities based
-    on a count and index.
+    Make a slice of a list of entities based on a count and index.
     """
 
     return itertools.islice(entities, index, index + count)
