@@ -17,6 +17,8 @@ except ImportError:
         from cgi import parse_qs
     ENCODED_QUERY = True
 
+from cgi import FieldStorage
+
 from httpexceptor import HTTP400
 
 from tiddlyweb.filters import parse_for_filters
@@ -47,27 +49,16 @@ class Query(object):
         query parameters. Put the results in ``tiddlyweb.query`` in
         environ. The query names and values are decoded from UTF-8 to
         unicode.
+
+        If there are file uploads in posted form data, the files are
+        not put into ``tiddlyweb.query``. Instead the file handles are
+        appended to ``tiddlyweb.input_files``.
         """
         content_type = environ.get('CONTENT_TYPE', '')
         environ['tiddlyweb.query'] = {}
-        if environ['REQUEST_METHOD'].upper() == 'POST' and \
-                content_type.startswith('application/x-www-form-urlencoded'):
-            try:
-                try:
-                    length = environ['CONTENT_LENGTH']
-                    content = read_request_body(environ, length)
-                    if not ENCODED_QUERY:
-                        content = content.decode('UTF-8')
-                except KeyError as exc:
-                    raise HTTP400('Invalid post, unable to read content: %s'
-                            % exc)
-                posted_data = parse_qs(content, keep_blank_values=True)
-                _update_tiddlyweb_query(environ, posted_data,
-                        encoded=ENCODED_QUERY)
-            except UnicodeDecodeError as exc:
-                raise HTTP400(
-                        'Invalid encoding in query data, utf-8 required: %s',
-                        exc)
+        environ['tiddlyweb.input_files'] = []
+        if _cgi_post(environ, content_type):
+            _process_post(environ, content_type)
         filters, leftovers = parse_for_filters(
                 environ.get('QUERY_STRING', ''), environ)
         query_data = parse_qs(leftovers, keep_blank_values=True)
@@ -81,9 +72,71 @@ class Query(object):
 
 
 def _update_tiddlyweb_query(environ, data, encoded=True):
+    """
+    Update ``tiddlyweb.query`` with decoded form data.
+    """
     if encoded:
         environ['tiddlyweb.query'].update(dict(
             [(unicode(key, 'UTF-8'), [unicode(value, 'UTF-8')
                 for value in values]) for key, values in data.items()]))
     else:
         environ['tiddlyweb.query'].update(data)
+
+
+def _cgi_post(environ, content_type):
+    """
+    Test if there is POST form data to handle.
+    """
+    return (environ['REQUEST_METHOD'].upper() == 'POST'
+            and (
+                content_type.startswith('application/x-www-form-urlencoded')
+                or content_type.startswith('multipart/form-data')))
+
+
+def _process_post(environ, content_type):
+    """
+    Process posted form data.
+    """
+    try:
+        if content_type.startswith('application/x-www-form-urlencoded'):
+            posted_data = _process_encodedform(environ)
+        elif content_type.startswith('multipart/form-data'):
+            posted_data = _process_multipartform(environ)
+        _update_tiddlyweb_query(environ, posted_data, encoded=ENCODED_QUERY)
+    except UnicodeDecodeError as exc:
+        raise HTTP400(
+                'Invalid encoding in query data, utf-8 required: %s',
+                exc)
+
+
+def _process_encodedform(environ):
+    """
+    Read ``application/x-www-form-urlencoded`` from the request
+    body and parse for form data and return.
+    """
+    try:
+        length = environ['CONTENT_LENGTH']
+        content = read_request_body(environ, length)
+        if not ENCODED_QUERY:
+            content = content.decode('UTF-8')
+    except KeyError as exc:
+        raise HTTP400('Invalid post, unable to read content: %s' % exc)
+    return parse_qs(content, keep_blank_values=True)
+
+
+def _process_multipartform(environ):
+    """
+    Read ``multipart/form-data`` using ``FieldStorage``, return
+    a dictionary of form data and set ``tiddlyweb.input_files``
+    to a list of available files.
+    """
+    posted_data = {}
+    field_storage = FieldStorage(fp=environ['wsgi.input'],
+            environ=environ, keep_blank_values=True)
+    for key in field_storage.keys():
+        if field_storage[key].filename:
+            environ['tiddlyweb.input_files'].append(
+                    field_storage[key])
+        else:
+            posted_data[key] = field_storage.getlist(key)
+    return posted_data
