@@ -2,13 +2,9 @@
 General utility routines shared by various web related modules.
 """
 
-import Cookie
-import urllib
 from datetime import datetime
-try:
-    from email.utils import parsedate
-except ImportError:  # Python < 2.5
-    from email.Utils import parsedate
+
+from email.utils import parsedate
 
 from httpexceptor import HTTP415, HTTP400, HTTP304
 
@@ -17,6 +13,13 @@ from tiddlyweb.model.tiddler import timestring_to_datetime, current_timestring
 from tiddlyweb.serializer import Serializer
 from tiddlyweb.util import sha
 
+from tiddlyweb.fixups import SimpleCookie, quote, unquote
+
+try:
+    unicode
+except NameError:
+    unicode = str
+
 
 def check_bag_constraint(environ, bag, constraint):
     """
@@ -31,7 +34,7 @@ def check_bag_constraint(environ, bag, constraint):
         usersign = environ['tiddlyweb.usersign']
         bag = store.get(bag)
         bag.policy.allows(usersign, constraint)
-    except (PermissionsError), exc:
+    except (PermissionsError) as exc:
         # XXX this throws away traceback info
         msg = 'for bag %s: %s' % (bag.name, exc)
         raise exc.__class__(msg)
@@ -86,19 +89,13 @@ def content_length_and_type(environ):
 
 def get_route_value(environ, name):
     """
-    Retrieve and decode ``name`` from UTF-8 data provided in WSGI route.
+    Retrieve and decode ``name`` from data provided in WSGI route.
 
     If ``name`` is not present in the route, allow KeyError to raise.
-
-    If found data is not URI escaped UTF-8, raise a ``400``.
     """
-    try:
-        value = environ['wsgiorg.routing_args'][1][name]
-        value = urllib.unquote(value).decode('utf-8')
-    except UnicodeDecodeError, exc:
-        raise HTTP400('incorrect encoding for %s, UTF-8 required: %s'
-                % (name, exc))
-    return value
+    value = environ['wsgiorg.routing_args'][1][name]
+    value = unquote(value)
+    return value.replace('%2F', '/')
 
 
 def get_serialize_type(environ, collection=False):
@@ -119,7 +116,7 @@ def get_serialize_type(environ, collection=False):
     if collection and ext and ext not in extension_types:
         accept = [None]
 
-    if type(accept) == str:
+    if type(accept) == unicode or type(accept) == str:
         accept = [accept]
 
     while len(accept) and serialize_type is None:
@@ -209,9 +206,10 @@ def make_cookie(name, value, mac_key=None, path=None,
     expires value. If ``expires`` is provided, its value should be
     in seconds.
     """
-    cookie = Cookie.SimpleCookie()
+    cookie = SimpleCookie()
 
-    value = value.encode('utf-8')
+    # XXX: backwards to 2.x?
+    #value = value.encode('utf-8')
 
     if mac_key:
         secret_string = sha('%s%s' % (value, mac_key)).hexdigest()
@@ -245,7 +243,7 @@ def read_request_body(environ, length):
         length = int(length)
         input_handle = environ['wsgi.input']
         return input_handle.read(length)
-    except (KeyError, ValueError, IOError), exc:
+    except (KeyError, ValueError, IOError) as exc:
         raise HTTP400('Error reading request body: %s', exc)
 
 
@@ -283,7 +281,7 @@ def encode_name(name):
     Encode a unicode value as utf-8 and then URL encode that
     string. Use for entity titles in URLs.
     """
-    return urllib.quote(name.encode('utf-8'), safe=".!~*'()")
+    return quote(name.encode('utf-8'), safe=".!~*'()")
 
 
 def html_encode(text):
